==> vtiger-4.0p1_1.tbz: www/vtiger/modules/Activities/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Activities/language/en_us.lang.php,v 1.11 2005/03/28 06:34:23 rank Exp $
 * Description:  Defines the English language pack for the Account module.
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Activities',
'LBL_MODULE_TITLE'=>'Activities: Home',
'LBL_SEARCH_FORM_TITLE'=>'Activity Search',
'LBL_LIST_FORM_TITLE'=>'Activity List',
'LBL_NEW_FORM_TITLE'=>'New Activity',
'LBL_TASK_INFORMATION'=>'Task Information',
'LBL_EVENT_INFORMATION'=>'Event Information',

'LBL_NAME'=>'Subject:',
'LBL_CONTACT_NAME'=>'Contact Name:',
'LBL_OPEN_ACTIVITIES'=>'Open Activities',
'LBL_ACTIVITY'=>'Activity:',
'LBL_HISTORY'=>'History',
'LBL_UPCOMING'=>"My Upcoming Activities",
'LBL_TODAY'=>'through ',

'LBL_NEW_TASK_BUTTON_TITLE'=>'New Task [Alt+N]',
'LBL_NEW_TASK_BUTTON_KEY'=>'N',
'LBL_NEW_TASK_BUTTON_LABEL'=>'New Task',
'LBL_SCHEDULE_MEETING_BUTTON_TITLE'=>'Schedule Meeting [Alt+M]',
'LBL_SCHEDULE_MEETING_BUTTON_KEY'=>'M',
'LBL_SCHEDULE_MEETING_BUTTON_LABEL'=>'Schedule Meeting',
'LBL_SCHEDULE_CALL_BUTTON_TITLE'=>'Schedule Call [Alt+C]',
'LBL_SCHEDULE_CALL_BUTTON_KEY'=>'C',
'LBL_SCHEDULE_CALL_BUTTON_LABEL'=>'Schedule Call',
'LBL_NEW_NOTE_BUTTON_TITLE'=>'New Note [Alt+T]',
'LBL_NEW_ATTACH_BUTTON_TITLE'=>'Attach File [Alt+F]',
'LBL_NEW_NOTE_BUTTON_KEY'=>'T',
'LBL_NEW_ATTACH_BUTTON_KEY'=>'F',
'LBL_NEW_NOTE_BUTTON_LABEL'=>'New Note',
'LBL_NEW_ATTACH_BUTTON_LABEL'=>'Attach File',
'LBL_TRACK_EMAIL_BUTTON_TITLE'=>'Track Email [Alt+K]',
'LBL_TRACK_EMAIL_BUTTON_KEY'=>'K',
'LBL_TRACK_EMAIL_BUTTON_LABEL'=>'Track Email',

'LBL_LIST_CLOSE'=>'Close',
'LBL_LIST_STATUS'=>'Status',
'LBL_LIST_CONTACT'=>'Contact',
'LBL_LIST_RELATED_TO'=>'Related to',
'LBL_LIST_DUE_DATE'=>'Due Date',
'LBL_LIST_DATE'=>'Date',
'LBL_LIST_SUBJECT'=>'Subject',
'LBL_LIST_LAST_MODIFIED'=>'Last Modified',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the account.",
'NTC_NONE_SCHEDULED'=>'None scheduled.',

// Added fields for Attachments in Activities/SubPanelView.php
'LBL_ATTACHMENTS'=>'Attachments',
'LBL_NEW_ATTACHMENT'=>'New Attachment',

//Added fields after RC1 - Release
'LBL_ALL'=>'All',
'LBL_CALL'=>'Call',
'LBL_MEETING'=>'Meeting',
'LBL_TASK'=>'Task',

//Added for 4GA Release
'Subject'=>'Subject',
'Assigned To'=>'Assigned To',
'Start Date & Time'=>'Start Date & Time',
'Time Start'=>'Time Start',
'Due Date'=>'Due Date',
'Related To'=>'Related To',
'Contact Name'=>'Contact Name',
'Status'=>'Status',
'Priority'=>'Priority',
'Send Notification'=>'Send Notification',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Activity Type'=>'Activity Type',
'Description'=>'Description',
'Duration'=>'Duration',
'Duration Minutes'=>'Duration Minutes',
'Location'=>'Location',

);

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/Activities/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Activities/language/en_us.lang.php,v 1.11 2005/03/28 06:34:23 rank Exp $
 * Description:  Defines the English language pack for the Account module.
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Activities',
'LBL_MODULE_TITLE'=>'Activities: Home',
'LBL_SEARCH_FORM_TITLE'=>'Activity Search',
'LBL_LIST_FORM_TITLE'=>'Activity List',
'LBL_NEW_FORM_TITLE'=>'New Activity',
'LBL_TASK_INFORMATION'=>'Task Information',
'LBL_EVENT_INFORMATION'=>'Event Information',

'LBL_NAME'=>'Subject:',
'LBL_CONTACT_NAME'=>'Contact Name:',
'LBL_OPEN_ACTIVITIES'=>'Open Activities',
'LBL_ACTIVITY'=>'Activity:',
'LBL_HISTORY'=>'History',
'LBL_UPCOMING'=>"My Upcoming and Pending Activities",
'LBL_TODAY'=>'through ',

'LBL_NEW_TASK_BUTTON_TITLE'=>'New Task [Alt+N]',
'LBL_NEW_TASK_BUTTON_KEY'=>'N',
'LBL_NEW_TASK_BUTTON_LABEL'=>'New Task',
'LBL_SCHEDULE_MEETING_BUTTON_TITLE'=>'Schedule Meeting [Alt+M]',
'LBL_SCHEDULE_MEETING_BUTTON_KEY'=>'M',
'LBL_SCHEDULE_MEETING_BUTTON_LABEL'=>'Schedule Meeting',
'LBL_SCHEDULE_CALL_BUTTON_TITLE'=>'Schedule Call [Alt+C]',
'LBL_SCHEDULE_CALL_BUTTON_KEY'=>'C',
'LBL_SCHEDULE_CALL_BUTTON_LABEL'=>'Schedule Call',
'LBL_NEW_NOTE_BUTTON_TITLE'=>'New Note [Alt+T]',
'LBL_NEW_ATTACH_BUTTON_TITLE'=>'Attach File [Alt+F]',
'LBL_NEW_NOTE_BUTTON_KEY'=>'T',
'LBL_NEW_ATTACH_BUTTON_KEY'=>'F',
'LBL_NEW_NOTE_BUTTON_LABEL'=>'New Note',
'LBL_NEW_ATTACH_BUTTON_LABEL'=>'Attach File',
'LBL_TRACK_EMAIL_BUTTON_TITLE'=>'Track Email [Alt+K]',
'LBL_TRACK_EMAIL_BUTTON_KEY'=>'K',
'LBL_TRACK_EMAIL_BUTTON_LABEL'=>'Track Email',

'LBL_LIST_CLOSE'=>'Close',
'LBL_LIST_STATUS'=>'Status',
'LBL_LIST_CONTACT'=>'Contact',
//Added for 4.2 release for Account column support as shown by Fredy
'LBL_LIST_ACCOUNT'=>'Account',
'LBL_LIST_RELATED_TO'=>'Related to',
'LBL_LIST_DUE_DATE'=>'Due Date',
'LBL_LIST_DATE'=>'Date',
'LBL_LIST_SUBJECT'=>'Subject',
'LBL_LIST_LAST_MODIFIED'=>'Last Modified',
'LBL_LIST_RECURRING_TYPE'=>'Recurring Type',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the account.",
'NTC_NONE_SCHEDULED'=>'None scheduled.',

// Added fields for Attachments in Activities/SubPanelView.php
'LBL_ATTACHMENTS'=>'Attachments',
'LBL_NEW_ATTACHMENT'=>'New Attachment',

//Added fields after RC1 - Release
'LBL_ALL'=>'All',
'LBL_CALL'=>'Call',
'LBL_MEETING'=>'Meeting',
'LBL_TASK'=>'Task',

//Added for 4GA Release
'Subject'=>'Subject',
'Assigned To'=>'Assigned To',
'Start Date & Time'=>'Start Date & Time',
'Time Start'=>'Time Start',
'Due Date'=>'Due Date',
'Related To'=>'Related To',
'Contact Name'=>'Contact Name',
'Status'=>'Status',
'Priority'=>'Priority',
'Send Notification'=>'Send Notification',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Activity Type'=>'Activity Type',
'Description'=>'Description',
'Duration'=>'Duration',
'Duration Minutes'=>'Duration Minutes',
'Location'=>'Location',

//Added for Send Reminder 4.2 release
'Send Reminder'=>'Send Reminder',
'LBL_YES'=>'Yes',
'LBL_NO'=>'No',
'LBL_DAYS'=>'days',
'LBL_MINUTES'=>'minutes',
'LBL_HOURS'=>'hours',
'LBL_BEFORE_EVENT'=>'before event',
//Added for CustomView 4.2 Release
'Close'=>'Close',
'Start Date'=>'Start Date',
'Type'=>'Type',
'End Date'=>'End Date',
'Recurrence'=> 'Recurring Events',
'Recurring Type'=> 'Recurring Type',
//Activities - Notification Error
'LBL_NOTIFICATION_ERROR'=>'Mail Error : Please check your outgoing mail server configuration in Settings->Outgoing Mail Server Configuration OR MailId for the present user is not Configured',


);

?>
